@@ -18,7 +18,17 @@ var CLASS_NAME = 'jupyter-widgets-view';
 var mngr = require("./manager");
 require("./save_state");
 require("./embed_widgets");
-var PhosphorWidget = require("@phosphor/widgets");
+var PhosphorWidget = require("@lumino/widgets");
+
+var NOTEBOOK_VERSION_INFO = Jupyter.version.split('.');
+var NOTEBOOK_MAJOR = parseInt(NOTEBOOK_VERSION_INFO[0]);
+var NOTEBOOK_MINOR = parseInt(NOTEBOOK_VERSION_INFO[1]);
+var NOTEBOOK_PATCH = parseInt(NOTEBOOK_VERSION_INFO[2]);
+
+var RENDER_SHOULD_THROW =
+  NOTEBOOK_MAJOR > 6 ||
+  (NOTEBOOK_MAJOR == 6 && NOTEBOOK_MINOR > 4) ||
+  (NOTEBOOK_MAJOR == 6 && NOTEBOOK_MINOR == 4 && NOTEBOOK_PATCH > 4);
 
 /**
  * Create a widget manager for a kernel instance.
@@ -104,12 +114,19 @@ function register_events(Jupyter, events, outputarea) {
         // data is a model id
         var manager = Jupyter.notebook && Jupyter.notebook.kernel && Jupyter.notebook.kernel.widget_manager;
         if (!manager) {
-            node.textContent = "Error rendering Jupyter widget: missing widget manager";
+            var msg = 'Error rendering Jupyter widget: missing widget manager';
+            if (RENDER_SHOULD_THROW) {
+                throw new Error(msg);
+            }
+            node.textContent = msg;
             return;
         }
 
         // Missing model id means the view was removed. Hide this element.
         if (data.model_id === '') {
+            if (RENDER_SHOULD_THROW) {
+                throw new Error('Jupyter Widgets model not found');
+            }
             node.style.display = 'none';
             return;
         }
@@ -134,7 +151,13 @@ function register_events(Jupyter, events, outputarea) {
                 })
             });
         } else {
-            node.textContent = 'A Jupyter widget could not be displayed because the widget state could not be found. This could happen if the kernel storing the widget is no longer available, or if the widget state was not saved in the notebook. You may be able to create the widget by running the appropriate cells.';
+          var msg =
+              'A Jupyter widget could not be displayed because the widget state could not be found. This could happen if the kernel storing the widget is no longer available, or if the widget state was not saved in the notebook. You may be able to create the widget by running the appropriate cells.';
+          if (RENDER_SHOULD_THROW) {
+              throw new Error(msg);
+          }
+          node.textContent = msg;
+          return;
         }
     }
 
@@ -146,6 +169,7 @@ function register_events(Jupyter, events, outputarea) {
         element.append(toinsert);
         return toinsert;
     };
+
     // Register mime type with the output area
     outputarea.OutputArea.prototype.register_mime_type(MIME_TYPE, append_mime, {
         // An output widget could contain arbitrary user javascript
@@ -162,7 +186,7 @@ function load_ipython_extension () {
             "base/js/events",
             "notebook/js/outputarea"
         ], function(Jupyter, events, outputarea) {
-            require("@phosphor/widgets/style/index.css");
+            require("@lumino/widgets/style/index.css");
             require("@jupyter-widgets/base/css/index.css");
             require('@jupyter-widgets/controls/css/widgets.css');
             register_events(Jupyter, events, outputarea);
